@@ -19,8 +19,16 @@
 #
 ##################################################################
 
+#import system library
+import sys
 #import modis library
-from pymodis import parsemodis, optparse_required
+try:
+    from pymodis import optparse_gui
+    wxpython = True
+except:
+    wxpython = False
+from pymodis import parsemodis
+from pymodis import optparse_required
 
 
 def readDict(dic):
@@ -30,11 +38,16 @@ def readDict(dic):
         out += "%s = %s\n" % (k, v)
     return out
 
+
 def main():
     """Main function"""
     #usage
     usage = "usage: %prog [options] hdf_files_list"
-    parser = optparse_required.OptionParser(usage=usage)
+    if 1 == len(sys.argv) and wxpython:
+        option_parser_class = optparse_gui.OptionParser
+    else:
+        option_parser_class = optparse_required.OptionParser
+    parser = option_parser_class(usage=usage, description='modis_multiparse')
     #spatial extent
     parser.add_option("-b", action="store_true", dest="bound", default=False,
                       help="print the values related to the spatial max extent")
@@ -44,8 +57,11 @@ def main():
 
     (options, args) = parser.parse_args()
     #create modis object
+    if len(args) == 0 and not wxpython:
+        parser.print_help()
+        sys.exit(1)
     if len(args) < 2:
-        parser.error("You have to pass the name of HDF files")
+        parser.error("You have to define the name of HDF files")
     modisOgg = parsemodis.parseModisMulti(args)
 
     if options.bound:
@@ -55,9 +71,8 @@ def main():
         modisOgg.writexml(options.output)
         print "%s write correctly" % options.output
     else:
-        parser.error("You have to chose at least an option")
+        parser.error("You have to choose at least one option")
 
 #add options
 if __name__ == "__main__":
     main()
-
